@@ -86,7 +86,7 @@
 #define KWALLET_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWALLET_NO_DEPRECATED
-#  define KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
+#  define KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
 #endif
 #ifdef KWALLET_NO_DEPRECATED_WARNINGS
 #  define KWALLET_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWALLET_DEPRECATED_WARNINGS_SINCE KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWALLET_DEPRECATED_WARNINGS_SINCE 0x55f00
+#    define KWALLET_DEPRECATED_WARNINGS_SINCE 0x56000
 #  endif
 #endif
 
@@ -180,7 +180,7 @@
 #define KWALLET_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWALLET_NO_DEPRECATED
-#  define KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
+#  define KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
 #endif
 #ifdef KWALLET_NO_DEPRECATED_WARNINGS
 #  define KWALLET_DEPRECATED_WARNINGS_SINCE 0
@@ -190,7 +190,7 @@
 #  ifdef KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWALLET_DEPRECATED_WARNINGS_SINCE KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWALLET_DEPRECATED_WARNINGS_SINCE 0x55f00
+#    define KWALLET_DEPRECATED_WARNINGS_SINCE 0x56000
 #  endif
 #endif
 
